# This file calculates the FDR-controlling t-statistics that are used in Table 5.
# The plots used in the paper are constructed in Stata 
# see file 2014-8-20_ethnicfig_corrected_theory_cps2.do

rm(list=ls())
library(foreign)

dat<-read.dta(file="coxappend.dta")

dat$upper <- dat$upper*100
dat$uppereneth <- dat$upper*dat$eneth
dat<-subset(dat, drop==0)

# run CG model
lin.mod <- lm(enpv ~ eneth + lnml + lmleneth + uppereneth + upper + enpres + proximit + proxpres, data=dat)

# save betas
beta.mod <- coefficients(lin.mod)
# save vcv
vcv.mod <- vcov(lin.mod)

# calculate MEs
mag <- seq(from=0.01, to=5, by=0.01)
me.vec <- beta.mod[2] + beta.mod[4]*mag
me.se <- sqrt( vcv.mod[2,2] + (mag^2)*vcv.mod[4,4] + 2*(mag)*(vcv.mod[2,4]) )

ci.hi <- me.vec + 1.684 * me.se
ci.lo <- me.vec - 1.684 * me.se

plot(me.vec ~ mag, type="l", ylim = c(-1, 4))
lines(ci.hi ~ mag, lty=2)
lines(ci.lo ~ mag, lty=2)

source("2015-8-20_fdr-interaction.R")
fdr.interaction(me.vec, me.se, df=lin.mod$df, level=0.90)                  # 1.853799

ci.hi <- me.vec + 1.853799 * me.se
ci.lo <- me.vec - 1.853799 * me.se

lines(ci.hi ~ mag, lty=2, lwd=2)
lines(ci.lo ~ mag, lty=2, lwd=2)











rm(list=ls())
library(foreign)
source("robust-se.R")
dat <- read.dta("legislative_figure.dta")
dat.nineties.est <- subset(dat, dat$nineties==1 & dat$old==1)

# run CG models
lin.mod <- lm(enep1 ~ eneg + logmag + logmag_eneg + uppertier_eneg + uppertier + proximity1 + proximity1_enpres + enpres, data=dat.nineties.est)

# save betas
beta.mod <- coefficients(lin.mod)
# save vcv
vcv.mod <- vcov(lin.mod)

# calculate MEs
mag <- seq(from=0.01, to=5, by=0.01)
me.vec <- beta.mod[2] + beta.mod[4]*mag
me.se <- sqrt( vcv.mod[2,2] + (mag^2)*vcv.mod[4,4] + 2*(mag)*(vcv.mod[2,4]) )

ci.hi <- me.vec + 1.697 * me.se
ci.lo <- me.vec - 1.697 * me.se

plot(me.vec ~ mag, type="l", ylim = c(-3, 6))
lines(ci.hi ~ mag, lty=2)
lines(ci.lo ~ mag, lty=2)

source("2015-8-20_fdr-interaction.R")
fdr.interaction(me.vec, me.se, df=lin.mod$df, level=0.90)                  # 4.233986

ci.hi <- me.vec + 4.233986 * me.se
ci.lo <- me.vec - 4.233986 * me.se

lines(ci.hi ~ mag, lty=2, lwd=2)
lines(ci.lo ~ mag, lty=2, lwd=2)







rm(list=ls())
library(foreign)
source("robust-se.R")
dat <- read.dta("legislative_figure.dta")
dat.est <- subset(dat, dat$old==1)

# run CG models
lin.mod <- lm(enep1 ~ eneg + logmag + logmag_eneg + uppertier_eneg + uppertier + proximity1 + proximity1_enpres + enpres, data=dat.est)
# save observations
obs.used <- which(rownames(dat.est) %in% rownames(lin.mod$mod))

# save betas
beta.mod <- coefficients(lin.mod)
# save vcv
vcv.mod <- robust.se(lin.mod, dat.est$country[obs.used])[[1]]

# calculate MEs
mag <- seq(from=0.01, to=5, by=0.01)
me.vec <- beta.mod[2] + beta.mod[4]*mag
me.se <- sqrt( vcv.mod[2,2] + (mag^2)*vcv.mod[4,4] + 2*(mag)*(vcv.mod[2,4]) )

ci.hi <- me.vec + 1.645 * me.se
ci.lo <- me.vec - 1.645 * me.se

plot(me.vec ~ mag, type="l", ylim = c(-1, 3))
lines(ci.hi ~ mag, lty=2)
lines(ci.lo ~ mag, lty=2)

source("2015-8-20_fdr-interaction.R")
fdr.interaction(me.vec, me.se, df=lin.mod$df, level=0.90)                  # 1.699901

ci.hi <- me.vec + 1.699901 * me.se
ci.lo <- me.vec - 1.699901 * me.se

lines(ci.hi ~ mag, lty=2, lwd=2)
lines(ci.lo ~ mag, lty=2, lwd=2)

